# Scenario 2

## Summary

Summary is required.
You can write summary in multilines.

## Steps

### Categories

- Function 1
- Function 2

### Description

Push the button.

### Expected

This is an expected result.

---

### Categories

- Function 1
- Function 3

### Description

Visit the website.

### Expected

404 Error.

---

### Categories

- Function 1
- Function 3

### Description

Execute the command.

### Expected

print "Hello World!"
